@@ -1,9 +1,8 @@
-from pydantic import BaseModel
 from typing import TYPE_CHECKING
 
 import aiokafka
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from .app import SchemaRegistration
     from .app import SubscriptionConsumer
 else:
@@ -26,17 +25,6 @@ New: {self.new}
 />"""
 
 
-class UnregisteredSchemaException(Exception):
-    def __init__(self, model: BaseModel = None):
-        self.model = model
-
-    def __str__(self) -> str:
-        return f"""<UnregisteredSchemaException
-(Attempted to send message for unregistered schema. Did you initialize the application?)
-Model: {self.model}
-/>"""
-
-
 class UnhandledMessage(Exception):
     ...
 
@@ -58,3 +46,7 @@ class AutoCommitError(ConsumerUnhealthyException):
 class ProducerUnhealthyException(Exception):
     def __init__(self, producer: aiokafka.AIOKafkaProducer):
         self.producer = producer
+
+
+class AppNotConfiguredException(Exception):
+    ...
